ArrayPtr

Struct ArrayPtr 

pub struct ArrayPtr<T>(/* private fields */);
A dynamically allocated array of T

Implementations

Source

impl<T> ArrayPtr<T>

pub fn new_uninit(count: usize) -> ArrayPtr<MaybeUninit<T>>

Allocate a new ArrayPtr<T> without initializing the memory

The number of elements is given by the input parameter count

pub fn shift_once(&mut self)
where T: Copy,

pub fn from_raw_parts(data: *mut T, len: usize) -> ArrayPtr<T>

Create a new ArrayPtr<T> from a pointer an an element-count

Safety

The caller must ensure that the pointer is non-null, and points to the number of elements specified.

Source

impl<T> ArrayPtr<MaybeUninit<T>>

pub unsafe fn assume_init(self) -> ArrayPtr<T>

Safety

Caller must guarantee each member of the ArrayPtr has been written to with a valid instance of T

Source

impl<T> ArrayPtr<T>
where T: Zero,

pub fn new_zeroed(count: usize) -> ArrayPtr<T>

Create a new ArrayPtr<T> by initializing it with T’s Zero implementation.

This function is feature-gated behind the num-traits feature.

Source

impl<T> ArrayPtr<T>
where T: Default,

pub fn new_default(count: usize) -> ArrayPtr<T>

Create a new ArrayPtr<T> by initializing it with T’s Default implementation.

Source

impl<T> ArrayPtr<T>

pub fn from_fn(count: usize, idx_map: impl Fn(usize) -> T) -> ArrayPtr<T>

Create a new ArrayPtr<T> from a provided closure and element-count

The closure will be invoked as an index-mapping from 0 up to the specified element-count.

pub const fn is_empty(&self) -> bool

Returns true if the underlying ArrayPtr<T> is empty

This should never happen.

pub const fn len(&self) -> usize

Returns the number of elements pointed to the ArrayPtr<T>

pub fn as_slice(&self) -> &[T]

Returns a shared slice-reference to the underlying data

pub fn as_mut_slice(&mut self) -> &mut [T]

Returns a mutable slice-reference to the underlying data

pub fn iter(&self) -> Iter<'_, T>

Returns an immutable iterator over underlying data

pub fn iter_mut(&mut self) -> IterMut<'_, T>

Returns a mutable iterator over underlying data