RingPtr

Struct RingPtr 

pub struct RingPtr<T> { /* private fields */ }

Implementations

Source

impl<T> RingPtr<T>

Source

impl<T> RingPtr<MaybeUninit<T>>

pub unsafe fn assume_init(self) -> RingPtr<T>

Safety

Caller must guarantee each member of the RingPtr has been written to with a valid instance of T

Source

impl<T> RingPtr<T>
where T: Zero,

pub fn new_zeroed(count: usize) -> RingPtr<T>

Source

impl<T> RingPtr<T>
where T: Default,

pub fn new_default(count: usize) -> RingPtr<T>

Source

impl<T> RingPtr<T>

pub const fn is_empty(&self) -> bool

Returns true if the capacity is zero or the current tail is the next head position

pub const fn len(&self) -> usize

Returns the ‘count’ of valid elements in the collection, not the capacity

pub const fn capacity(&self) -> usize

pub fn push(&mut self, val: T)

pub fn replace(&mut self, src: T) -> T

pub fn reset(&mut self)

pub fn pop(&mut self) -> Option<T>

pub fn peek(&self) -> &T

pub fn as_slice(&self) -> &[T]

pub fn as_mut_slice(&mut self) -> &mut [T]

pub fn iter(&self) -> Iter<'_, T>

pub fn iter_mut(&mut self) -> IterMut<'_, T>