pub struct RingPtr<T> { /* private fields */ }Implementations
Sourceimpl<T> RingPtr<T>
impl<T> RingPtr<T>
pub fn new_uninit(count: usize) -> RingPtr<MaybeUninit<T>>
Sourceimpl<T> RingPtr<MaybeUninit<T>>
impl<T> RingPtr<MaybeUninit<T>>
Sourcepub unsafe fn assume_init(self) -> RingPtr<T>
pub unsafe fn assume_init(self) -> RingPtr<T>
Sourceimpl<T> RingPtr<T>
impl<T> RingPtr<T>
Sourcepub const fn is_empty(&self) -> bool
pub const fn is_empty(&self) -> bool
Returns true if the capacity is zero or the current tail is the next head position
Sourcepub const fn len(&self) -> usize
pub const fn len(&self) -> usize
Returns the ‘count’ of valid elements in the collection, not the capacity
pub const fn capacity(&self) -> usize
pub fn push(&mut self, val: T)
pub fn replace(&mut self, src: T) -> T
pub fn reset(&mut self)
pub fn pop(&mut self) -> Option<T>
pub fn peek(&self) -> &T
pub fn as_slice(&self) -> &[T]
pub fn as_mut_slice(&mut self) -> &mut [T]
pub fn iter(&self) -> Iter<'_, T>
pub fn iter_mut(&mut self) -> IterMut<'_, T>